embassy-stm32

Crates

git

Versions

stm32u575oi

Flavors

Cordic16

Struct Cordic16 

pub struct Cordic16<'d, 'a, T: Instance> { /* private fields */ }
q1.15 related

Implementations

Source

impl<'d, 'a, T: Instance> Cordic16<'d, 'a, T>

q1.15 related

pub fn blocking_calc( &mut self, arg: &Aligned<A4, [Q16<15>]>, res: &mut Aligned<A4, [Q16<15>]>, ) -> Result<usize, CordicError>

Run a blocking CORDIC calculation in q1.15 format.

In q1.15 mode, each WDATA write / RDATA read contains two packed 16-bit values, so nargs and nres are always 1 (one register access = two values).

pub async fn async_calc<'b, W, R>( &mut self, write_dma: Peri<'b, W>, read_dma: Peri<'b, R>, irq: impl Binding<W::Interrupt, InterruptHandler<W>> + Binding<R::Interrupt, InterruptHandler<R>> + 'b, arg: &Aligned<A4, [Q16<15>]>, res: &mut Aligned<A4, [Q16<15>]>, ) -> Result<usize, CordicError>
where W: WriteDma<T>, R: ReadDma<T>,

Run an async CORDIC calculation in q1.15 format.

In q1.15 mode, each WDATA write / RDATA read contains two packed 16-bit values, so nargs and nres are always 1 (one register access = two values).